@@ -1,7 +1,8 @@
+#' @importFrom rgl rgl.triangles
+#' @importFrom geometry surf.tri
+#' @importFrom geometry delaunayn
 plot3dtriangles <- function(m,...){
-	r <- require(geometry, quietly=TRUE)
-	if(!r)stop("Please install package geometry")
-	tm <- try(t(geometry::surf.tri(m, geometry::delaunayn(m))))
+	tm <- try(t(surf.tri(m, delaunayn(m, options="Pp"))))
 	if(!inherits(tm, "try-error"))
 		rgl.triangles(m[tm,1], m[tm,2], m[tm,3],...)	
 	else
